'use strict';

module.exports = function (grunt) {
  // Load all grunt tasks
  require('load-grunt-tasks')(grunt);
  // Show elapsed time at the end
  require('time-grunt')(grunt);

  // Project configuration.
  grunt.initConfig({
    // Metadata.
    pkg: grunt.file.readJSON('package.json'),
    banner: '/*!\n' +
      '* <%%= pkg.name %> - for jQuery 1.7+\n' +
      '<%%= pkg.homepage ? "* " + pkg.homepage + "\\n" : "" %>' +
      '*\n' +
      '* Copyright <%%= grunt.template.today("yyyy") %>, <%%= pkg.author.name %> (http://clivewalkden.co.uk)\n' +
      '*\n' +
      '* @package <%%= pkg.description %>\n' +
      '* @author <%%= pkg.author.name %> (<%%= pkg.author.url %>)\n' +
      '* @version <%%= pkg.version %>\n' +
      '* @license <%%= props.license %>\n' +
      '* @copyright Copyright (c) <%%= grunt.template.today("yyyy") %> <%%= pkg.author.name %> (<%%= pkg.author.url %>)\n' +
      '* @date: <%%= grunt.template.today("yyyy-mm-dd") %>\n' +
      '*/\n\n',
    // Task configuration.
    clean: {
      files: ['dist']
    },
    concat: {
      options: {
        banner: '<%%= banner %>',
        stripBanners: true
      },
      dist: {
        src: ['src/<%%= pkg.name %>.js'],
        dest: 'dist/jquery.<%%= pkg.name %>.js'
      }
    },
    uglify: {
      options: {
        banner: '<%%= banner %>'
      },
      dist: {
        src: '<%%= concat.dist.dest %>',
        dest: 'dist/jquery.<%%= pkg.name %>.min.js'
      }
    },
    qunit: {
      all: {
        options: {
          urls: ['1.7.0','1.7.1','1.7.2','1.8.0','1.8.1','1.8.2','1.8.3','1.9.0','1.9.1','1.10.0','1.10.1','1.10.2','1.11.0','2.0.0','2.0.1','2.0.2','2.0.3','2.1.0'].map(function(version) {
            return 'http://localhost:<%%= connect.server.options.port %>/test/<%%= pkg.name %>.html?jquery=' + version;
          })
        }
      }
    },
    jshint: {
      options: {
        reporter: require('jshint-stylish')
      },
      gruntfile: {
        options: {
          jshintrc: '.jshintrc'
        },
        src: 'Gruntfile.js'
      },
      src: {
        options: {
          jshintrc: 'src/.jshintrc'
        },
        src: ['src/**/*.js']
      },
      test: {
        options: {
          jshintrc: 'test/.jshintrc'
        },
        src: ['test/**/*.js']
      }
    },
    watch: {
      gruntfile: {
        files: '<%%= jshint.gruntfile.src %>',
        tasks: ['jshint:gruntfile']
      },
      src: {
        files: '<%%= jshint.src.src %>',
        tasks: ['jshint:src', 'qunit']
      },
      test: {
        files: '<%%= jshint.test.src %>',
        tasks: ['jshint:test', 'qunit']
      }
    },
    connect: {
      server: {
        options: {
          //hostname: '*',
          port: 8085
        }
      }
    }
  });

  // Default task.
  grunt.registerTask('default', ['jshint', 'connect', 'qunit', 'clean', 'concat', 'uglify']);
  grunt.registerTask('server', function () {
    grunt.log.warn('The `server` task has been deprecated. Use `grunt serve` to start a server.');
    grunt.task.run(['serve']);
  });
  grunt.registerTask('serve', ['connect', 'watch']);
  grunt.registerTask('test', ['jshint', 'connect', 'qunit']);
};
